==> pipewire-docs-1%3A0.3.30-2-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/defs_8h.js <==
var defs_8h =
[
    [ "SPA_ALIGNED", "group__spa__utils.html#gac894bd2d39b2644e1bacf4b11c0a187d", null ],
    [ "spa_aprintf", "group__spa__utils.html#ga007f98725701a4b6debe365c7a5e0bbe", null ],
    [ "spa_assert", "group__spa__utils.html#gafa109f3532687323c8f8340f18a15220", null ],
    [ "spa_assert_not_reached", "group__spa__utils.html#ga6212956dcff36c69fa954f66efaefbcf", null ],
    [ "spa_assert_se", "group__spa__utils.html#ga48e64fde9ece326caf683b04597614a5", null ],
    [ "SPA_CLAMP", "group__spa__utils.html#ga33e30c1bdbba747c8c00077913d48411", null ],
    [ "SPA_CONTAINER_OF", "group__spa__utils.html#gaa495b586c261831b67f09c7f9851aa05", null ],
    [ "SPA_DEPRECATED", "group__spa__utils.html#ga933e7dba5e09dd618617b7b16c0d42fc", null ],
    [ "SPA_DIRECTION_REVERSE", "group__spa__utils.html#ga57aec3d89182594c8fef7be284f41fff", null ],
    [ "SPA_EXPORT", "group__spa__utils.html#gac1ac8f034b73e453c531d928cdfdd8b7", null ],
    [ "SPA_FALLTHROUGH", "group__spa__utils.html#gacbdd2b8d9e9137bbbd9a38f495c80263", null ],
    [ "SPA_FLAG_CLEAR", "group__spa__utils.html#gaceee1eb1469c2ab68034f5619913bc0d", null ],
    [ "SPA_FLAG_IS_SET", "group__spa__utils.html#gaa44a69e371d934ab026ae08af1d9b67e", null ],
    [ "SPA_FLAG_MASK", "group__spa__utils.html#gaf296ce57d6de2645675d2c89fdc8af0a", null ],
    [ "SPA_FLAG_SET", "group__spa__utils.html#ga006941b3f6423cec7b170b4434d8a799", null ],
    [ "SPA_FLAG_UPDATE", "group__spa__utils.html#ga3bca1a11d1c7e8404f9456580acf0676", null ],
    [ "SPA_FOR_EACH_ELEMENT", "group__spa__utils.html#ga895eccfd8032e0e9eec102e3b8442f12", null ],
    [ "SPA_FRACTION", "group__spa__utils.html#ga58dddf4d57e29beade3b44e156dea532", null ],
    [ "SPA_ID_INVALID", "group__spa__utils.html#ga6c3f9f95123f53da37d2bd173bd17ed1", null ],
    [ "SPA_IDX_INVALID", "group__spa__utils.html#gaabdb5fd45bca56878896d7c28204fb88", null ],
    [ "SPA_INT_TO_PTR", "group__spa__utils.html#gafa5449ce6a2352b7966fa923892a46fa", null ],
    [ "SPA_IS_ALIGNED", "group__spa__utils.html#gab4c957beedd4012fd0513f174d7b8b1a", null ],
    [ "SPA_LIKELY", "group__spa__utils.html#ga9a615b131c891caac9a73e05b35da09c", null ],
    [ "SPA_MAX", "group__spa__utils.html#gafd41067bab5e0c66b38886f672702dd4", null ],
    [ "SPA_MEMBER", "group__spa__utils.html#gaad6949f0b0a59d29fdf35ff11ebf83cb", null ],
    [ "SPA_MEMBER_ALIGN", "group__spa__utils.html#ga5e46f399b745cda80c6a5a8ab8d5d14f", null ],
    [ "spa_memcpy", "group__spa__utils.html#gadd03b1b1f299d9249de66ff32bc34569", null ],
    [ "spa_memmove", "group__spa__utils.html#gaf7a3ad1f0f015a14f7719022fc6e5a0e", null ],
    [ "spa_memzero", "group__spa__utils.html#gae2c26bfcbc2a33bcfae86018b35fab20", null ],
    [ "SPA_MIN", "group__spa__utils.html#ga06647c110a0382a09bea681a14634f64", null ],
    [ "SPA_MSEC_PER_SEC", "group__spa__utils.html#gacc9914448bc9fd68ae5ccf004c401bcb", null ],
    [ "SPA_N_ELEMENTS", "group__spa__utils.html#ga796e3d4570d8d539ea5886074a646a11", null ],
    [ "spa_nop", "group__spa__utils.html#gae8d35b670e70b6cdba489ca76b5791d4", null ],
    [ "SPA_NSEC_PER_MSEC", "group__spa__utils.html#ga6259b69a24b203050fe69cacac57748a", null ],
    [ "SPA_NSEC_PER_SEC", "group__spa__utils.html#ga7b3174639eb92d4c045a2bbc72a035df", null ],
    [ "SPA_NSEC_PER_USEC", "group__spa__utils.html#ga6c2a22d6e106ac2f2d69d66a8ed35bd0", null ],
    [ "SPA_POINT", "group__spa__utils.html#gaf42b2cfc208dc17d25624d84f962b25d", null ],
    [ "SPA_PRINTF_FUNC", "group__spa__utils.html#gab30712bed8289c9218eb66d9bfeeab78", null ],
    [ "SPA_PTR_ALIGN", "group__spa__utils.html#ga4a50fbd4b694e2826233b6d54ef3b5a8", null ],
    [ "SPA_PTR_ALIGNMENT", "group__spa__utils.html#ga26f69327ba25a67c5120805511190740", null ],
    [ "SPA_PTR_TO_INT", "group__spa__utils.html#gac8080acabcd35c560a15df5e1801afa1", null ],
    [ "SPA_PTR_TO_UINT32", "group__spa__utils.html#gaa92b4913ce779aa401cc714ae829eace", null ],
    [ "SPA_PTRDIFF", "group__spa__utils.html#gaec22d2ead4ec1771760219dc16f24709", null ],
    [ "SPA_PTROFF", "group__spa__utils.html#gae8ab0b793d870a9725897e695454c12b", null ],
    [ "SPA_PTROFF_ALIGN", "group__spa__utils.html#ga59196e4cfb0d8c0a8bdcd909cbbea334", null ],
    [ "SPA_RECTANGLE", "group__spa__utils.html#gafdd52836cf3dfdc12328615ac44c18e0", null ],
    [ "SPA_REGION", "group__spa__utils.html#gace48f5bc6836a62c328fcac938f8ea6e", null ],
    [ "SPA_RESTRICT", "group__spa__utils.html#ga3fecbba7e4f85f539f62c8db39f12b0a", null ],
    [ "spa_return_if_fail", "group__spa__utils.html#gaa360562916c7e9ab66865f277477f4e6", null ],
    [ "spa_return_val_if_fail", "group__spa__utils.html#ga632087e970399228667a768ba8424f4e", null ],
    [ "SPA_ROUND_DOWN_N", "group__spa__utils.html#gabfdffcb3a4e4e4a488a2ff714e01b3ca", null ],
    [ "SPA_ROUND_UP_N", "group__spa__utils.html#ga3404aa33acd9e8316fb33ebd146446f0", null ],
    [ "SPA_SENTINEL", "group__spa__utils.html#gad485e752b9b897f6434724f669ba72ae", null ],
    [ "SPA_STRINGIFY", "group__spa__utils.html#ga2157cfb3de1793302e5d08958bdc8ab2", null ],
    [ "SPA_STRINGIFY_1", "group__spa__utils.html#gaa3a2b836ca54d95f207f5557988db748", null ],
    [ "SPA_SWAP", "group__spa__utils.html#ga7f23cca5e034297bbd1b6860d1dbfdbc", null ],
    [ "SPA_TIME_INVALID", "group__spa__utils.html#ga1b605788d4782d77eb54b75f258413b9", null ],
    [ "SPA_TIMESPEC_TO_NSEC", "group__spa__utils.html#gad5b23b2094b330aacd6489da1c8fa7b7", null ],
    [ "SPA_TIMESPEC_TO_USEC", "group__spa__utils.html#ga3d65c899d0f8937244ed2893d1841f6f", null ],
    [ "SPA_TIMEVAL_TO_NSEC", "group__spa__utils.html#ga7b184a799c7168d95deaecab5208f557", null ],
    [ "SPA_TIMEVAL_TO_USEC", "group__spa__utils.html#gafdcbf720fb6f9ab8a91a0eacdbc3beca", null ],
    [ "SPA_TYPECHECK", "group__spa__utils.html#ga1179685eef5a041a5c8e60a9a6483048", null ],
    [ "SPA_UINT32_TO_PTR", "group__spa__utils.html#gaf8cdb131feb79dfd1d9d1097cb89c052", null ],
    [ "SPA_UNLIKELY", "group__spa__utils.html#gac30327f8b5e6a9c6f9129a73581d09dc", null ],
    [ "SPA_UNUSED", "group__spa__utils.html#ga1f57dfee056b657ddcd2bc69a7f45bce", null ],
    [ "SPA_USEC_PER_MSEC", "group__spa__utils.html#ga4a52677c41f0a787a3c6624f18647cb6", null ],
    [ "SPA_USEC_PER_SEC", "group__spa__utils.html#gaf9f1e071334f25ea8580f2509d17fcdd", null ],
    [ "spa_zero", "group__spa__utils.html#ga3625c72ccb164919faaf2a3c5a37e9c2", null ],
    [ "spa_direction", "group__spa__utils.html#ga9f2fae4a58cc2e3fdf568d1afc9dc7c1", [
      [ "SPA_DIRECTION_INPUT", "group__spa__utils.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1a48000c4ffb67d7fcba31225d2ca9600d", null ],
      [ "SPA_DIRECTION_OUTPUT", "group__spa__utils.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1ad27b9a94c88677dfa8681ec43abac456", null ]
    ] ]
];

==> pipewire-docs-1%3A0.3.38-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/defs_8h.js <==
var defs_8h =
[
    [ "SPA_ABS", "group__spa__utils.html#gaf5c3a152070995c325caaaf0333269c0", null ],
    [ "SPA_ALIGNED", "group__spa__utils.html#gac894bd2d39b2644e1bacf4b11c0a187d", null ],
    [ "spa_aprintf", "group__spa__utils.html#ga007f98725701a4b6debe365c7a5e0bbe", null ],
    [ "spa_assert", "group__spa__utils.html#gafa109f3532687323c8f8340f18a15220", null ],
    [ "spa_assert_not_reached", "group__spa__utils.html#ga6212956dcff36c69fa954f66efaefbcf", null ],
    [ "spa_assert_se", "group__spa__utils.html#ga48e64fde9ece326caf683b04597614a5", null ],
    [ "SPA_CLAMP", "group__spa__utils.html#ga33e30c1bdbba747c8c00077913d48411", null ],
    [ "SPA_CONTAINER_OF", "group__spa__utils.html#gaa495b586c261831b67f09c7f9851aa05", null ],
    [ "SPA_DEPRECATED", "group__spa__utils.html#ga933e7dba5e09dd618617b7b16c0d42fc", null ],
    [ "SPA_DIRECTION_REVERSE", "group__spa__utils.html#ga57aec3d89182594c8fef7be284f41fff", null ],
    [ "SPA_EXPORT", "group__spa__utils.html#gac1ac8f034b73e453c531d928cdfdd8b7", null ],
    [ "SPA_FALLTHROUGH", "group__spa__utils.html#gacbdd2b8d9e9137bbbd9a38f495c80263", null ],
    [ "SPA_FLAG_CLEAR", "group__spa__utils.html#gaceee1eb1469c2ab68034f5619913bc0d", null ],
    [ "SPA_FLAG_IS_SET", "group__spa__utils.html#gaa44a69e371d934ab026ae08af1d9b67e", null ],
    [ "SPA_FLAG_MASK", "group__spa__utils.html#gaf296ce57d6de2645675d2c89fdc8af0a", null ],
    [ "SPA_FLAG_SET", "group__spa__utils.html#ga006941b3f6423cec7b170b4434d8a799", null ],
    [ "SPA_FLAG_UPDATE", "group__spa__utils.html#ga3bca1a11d1c7e8404f9456580acf0676", null ],
    [ "SPA_FOR_EACH_ELEMENT", "group__spa__utils.html#ga895eccfd8032e0e9eec102e3b8442f12", null ],
    [ "SPA_FORMAT_ARG_FUNC", "group__spa__utils.html#gac8965bea56eb75da08e84a547bee992e", null ],
    [ "SPA_FRACTION", "group__spa__utils.html#ga58dddf4d57e29beade3b44e156dea532", null ],
    [ "SPA_ID_INVALID", "group__spa__utils.html#ga6c3f9f95123f53da37d2bd173bd17ed1", null ],
    [ "SPA_IDX_INVALID", "group__spa__utils.html#gaabdb5fd45bca56878896d7c28204fb88", null ],
    [ "SPA_INT_TO_PTR", "group__spa__utils.html#gafa5449ce6a2352b7966fa923892a46fa", null ],
    [ "SPA_IS_ALIGNED", "group__spa__utils.html#gab4c957beedd4012fd0513f174d7b8b1a", null ],
    [ "SPA_LIKELY", "group__spa__utils.html#ga9a615b131c891caac9a73e05b35da09c", null ],
    [ "SPA_MAX", "group__spa__utils.html#gafd41067bab5e0c66b38886f672702dd4", null ],
    [ "SPA_MEMBER", "group__spa__utils.html#gaad6949f0b0a59d29fdf35ff11ebf83cb", null ],
    [ "SPA_MEMBER_ALIGN", "group__spa__utils.html#ga5e46f399b745cda80c6a5a8ab8d5d14f", null ],
    [ "spa_memcpy", "group__spa__utils.html#gadd03b1b1f299d9249de66ff32bc34569", null ],
    [ "spa_memmove", "group__spa__utils.html#gaf7a3ad1f0f015a14f7719022fc6e5a0e", null ],
    [ "spa_memzero", "group__spa__utils.html#gae2c26bfcbc2a33bcfae86018b35fab20", null ],
    [ "SPA_MIN", "group__spa__utils.html#ga06647c110a0382a09bea681a14634f64", null ],
    [ "SPA_MSEC_PER_SEC", "group__spa__utils.html#gacc9914448bc9fd68ae5ccf004c401bcb", null ],
    [ "SPA_N_ELEMENTS", "group__spa__utils.html#ga796e3d4570d8d539ea5886074a646a11", null ],
    [ "spa_nop", "group__spa__utils.html#gae8d35b670e70b6cdba489ca76b5791d4", null ],
    [ "SPA_NORETURN", "group__spa__utils.html#ga01ba22304e834c86556e645614f65d84", null ],
    [ "SPA_NSEC_PER_MSEC", "group__spa__utils.html#ga6259b69a24b203050fe69cacac57748a", null ],
    [ "SPA_NSEC_PER_SEC", "group__spa__utils.html#ga7b3174639eb92d4c045a2bbc72a035df", null ],
    [ "SPA_NSEC_PER_USEC", "group__spa__utils.html#ga6c2a22d6e106ac2f2d69d66a8ed35bd0", null ],
    [ "SPA_POINT", "group__spa__utils.html#gaf42b2cfc208dc17d25624d84f962b25d", null ],
    [ "SPA_PRINTF_FUNC", "group__spa__utils.html#gab30712bed8289c9218eb66d9bfeeab78", null ],
    [ "SPA_PTR_ALIGN", "group__spa__utils.html#ga4a50fbd4b694e2826233b6d54ef3b5a8", null ],
    [ "SPA_PTR_ALIGNMENT", "group__spa__utils.html#ga26f69327ba25a67c5120805511190740", null ],
    [ "SPA_PTR_TO_INT", "group__spa__utils.html#gac8080acabcd35c560a15df5e1801afa1", null ],
    [ "SPA_PTR_TO_UINT32", "group__spa__utils.html#gaa92b4913ce779aa401cc714ae829eace", null ],
    [ "SPA_PTRDIFF", "group__spa__utils.html#gaec22d2ead4ec1771760219dc16f24709", null ],
    [ "SPA_PTROFF", "group__spa__utils.html#gae8ab0b793d870a9725897e695454c12b", null ],
    [ "SPA_PTROFF_ALIGN", "group__spa__utils.html#ga59196e4cfb0d8c0a8bdcd909cbbea334", null ],
    [ "SPA_RECTANGLE", "group__spa__utils.html#gafdd52836cf3dfdc12328615ac44c18e0", null ],
    [ "SPA_REGION", "group__spa__utils.html#gace48f5bc6836a62c328fcac938f8ea6e", null ],
    [ "SPA_RESTRICT", "group__spa__utils.html#ga3fecbba7e4f85f539f62c8db39f12b0a", null ],
    [ "spa_return_if_fail", "group__spa__utils.html#gaa360562916c7e9ab66865f277477f4e6", null ],
    [ "spa_return_val_if_fail", "group__spa__utils.html#ga632087e970399228667a768ba8424f4e", null ],
    [ "SPA_ROUND_DOWN_N", "group__spa__utils.html#gabfdffcb3a4e4e4a488a2ff714e01b3ca", null ],
    [ "SPA_ROUND_UP_N", "group__spa__utils.html#ga3404aa33acd9e8316fb33ebd146446f0", null ],
    [ "SPA_SENTINEL", "group__spa__utils.html#gad485e752b9b897f6434724f669ba72ae", null ],
    [ "SPA_STRINGIFY", "group__spa__utils.html#ga2157cfb3de1793302e5d08958bdc8ab2", null ],
    [ "SPA_STRINGIFY_1", "group__spa__utils.html#gaa3a2b836ca54d95f207f5557988db748", null ],
    [ "SPA_SWAP", "group__spa__utils.html#ga7f23cca5e034297bbd1b6860d1dbfdbc", null ],
    [ "SPA_TIME_INVALID", "group__spa__utils.html#ga1b605788d4782d77eb54b75f258413b9", null ],
    [ "SPA_TIMESPEC_TO_NSEC", "group__spa__utils.html#gad5b23b2094b330aacd6489da1c8fa7b7", null ],
    [ "SPA_TIMESPEC_TO_USEC", "group__spa__utils.html#ga3d65c899d0f8937244ed2893d1841f6f", null ],
    [ "SPA_TIMEVAL_TO_NSEC", "group__spa__utils.html#ga7b184a799c7168d95deaecab5208f557", null ],
    [ "SPA_TIMEVAL_TO_USEC", "group__spa__utils.html#gafdcbf720fb6f9ab8a91a0eacdbc3beca", null ],
    [ "SPA_TYPECHECK", "group__spa__utils.html#ga1179685eef5a041a5c8e60a9a6483048", null ],
    [ "SPA_UINT32_TO_PTR", "group__spa__utils.html#gaf8cdb131feb79dfd1d9d1097cb89c052", null ],
    [ "SPA_UNLIKELY", "group__spa__utils.html#gac30327f8b5e6a9c6f9129a73581d09dc", null ],
    [ "SPA_UNUSED", "group__spa__utils.html#ga1f57dfee056b657ddcd2bc69a7f45bce", null ],
    [ "SPA_USEC_PER_MSEC", "group__spa__utils.html#ga4a52677c41f0a787a3c6624f18647cb6", null ],
    [ "SPA_USEC_PER_SEC", "group__spa__utils.html#gaf9f1e071334f25ea8580f2509d17fcdd", null ],
    [ "spa_zero", "group__spa__utils.html#ga3625c72ccb164919faaf2a3c5a37e9c2", null ],
    [ "spa_direction", "group__spa__utils.html#ga9f2fae4a58cc2e3fdf568d1afc9dc7c1", [
      [ "SPA_DIRECTION_INPUT", "group__spa__utils.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1a48000c4ffb67d7fcba31225d2ca9600d", null ],
      [ "SPA_DIRECTION_OUTPUT", "group__spa__utils.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1ad27b9a94c88677dfa8681ec43abac456", null ]
    ] ]
];
